pub enum ParseError<'a> {
DwordToUsize(Dword),
InvalidFrameSize(Dword),
InvalidChunkSize(Dword),
Utf8Error(Utf8Error),
PaletteError(PaletteError),
InvalidFrameRange(Word, Word),
LayerIndexOutOfBounds,
InvalidPropertyType(Word),
Nom(Error<&'a [u8]>),
}Variants
DwordToUsize(Dword)
This variant is used when the conversion between DWORD (u32) to usize fails. The only way this can happen is when running this code on a 16-bit system.
InvalidFrameSize(Dword)
This variant is used when the frame size is <4
InvalidChunkSize(Dword)
This variant is used when the chunk size is <4
Utf8Error(Utf8Error)
This variant is used when a string does not contain
valid UTF-8 data and str::from_utf8 returned an error.
PaletteError(PaletteError)
The uses index colors but the palette could not be generated due to errors in the palette chunks.
InvalidFrameRange(Word, Word)
The range of frame indices was invalid (from > to)
LayerIndexOutOfBounds
This variant is used when a layer index is out of bounds (layer_index >= layer_count)
InvalidPropertyType(Word)
This variant is used when a unsupported property type is found in the user data.
Nom(Error<&'a [u8]>)
This variant is used when the nom combinators return an error.