Header

Struct Header 

pub struct Header {
Show 15 fields pub file_size: Dword, pub frames: Word, pub width: Word, pub height: Word, pub color_depth: ColorDepth, pub flags: Dword, pub speed: Word, pub transparent_index: Byte, pub color_count: Word, pub pixel_width: Byte, pub pixel_height: Byte, pub grid_x: Short, pub grid_y: Short, pub grid_width: Word, pub grid_height: Word,
}
A 128-byte header (same as FLC/FLI header, but with other magic number)

Fields

file_size: Dword

File size

frames: Word

Amount of frames in the body of the file

width: Word

Width in pixels

height: Word

Height in pixels

color_depth: ColorDepth

Color depth (bits per pixel)

flags: Dword

Flags: 1 = Layer opacity has valid value

speed: Word
👎Deprecated:

You should use the frame durations instead

Speed (milliseconds between frame, like in FLC files) DEPRECATED: You should use the frame duration field from each frame header

transparent_index: Byte

Palette entry (index) which represent transparent color in all non-background layers (only for Indexed sprites).

color_count: Word

The amount of colors in the palette

pixel_width: Byte

Pixel width (pixel ratio is “pixel width/pixel height”). If this or pixel height field is zero, pixel ratio is 1:1

pixel_height: Byte

Pixel height

grid_x: Short

X position of the grid

grid_y: Short

Y position of the grid

grid_width: Word

Grid width (zero if there is no grid, grid size is 16x16 on Aseprite by default)

grid_height: Word

Grid height (zero if there is no grid)