Module loader

Module loader 

This module contains the actual loader API. This API is based on the binary-module of this crate and does provide a convenience API for accessing layers, frames, tags and fully blended images.

Structs

AsepriteFile
This can be used to load an Aseprite file.
Frame
A frame in the file
FrameCel
A cel in a frame
Layer
A layer in the file
Tag
A tag in the file

Enums

LayerSelection
Pre-computed layer visibility selection for efficient per-frame filtering.
LoadImageError
Errors that can occur while decoding image pixel data.
LoadSpriteError
Errors that can occur while building the high-level AsepriteFile.

Functions

decompress
Decompress zlib-compressed image bytes into target.