pub enum LayerSelection {
Visible,
All,
Mask(Vec<bool>),
}Expand description
Pre-computed layer visibility selection for efficient per-frame filtering.
Created via AsepriteFile::select_layers.
Variants
Visible
Render visible layers as defined in the aseprite file.
All
Render all layers regardless of their visibility in the aseprite file.
Mask(Vec<bool>)
Render layers using a mask.