This module contains the actual loader API. This API is based on the
binary-module of this crate and does provide a convenience API for
accessing layers, frames, tags and fully blended images.
Structs
- Aseprite
File - This can be used to load an Aseprite file.
- Frame
- A frame in the file
- Frame
Cel - A cel in a frame
- Layer
- A layer in the file
- Tag
- A tag in the file
Enums
- Layer
Selection - Pre-computed layer visibility selection for efficient per-frame filtering.
- Load
Image Error - Errors that can occur while decoding image pixel data.
- Load
Sprite Error - Errors that can occur while building the high-level
AsepriteFile.
Functions
- decompress
- Decompress zlib-compressed image bytes into
target.