Module aseprite_loader::loader

source ·
This module contains the actual loader API. This API is based on the binary-module of this crate and does provide a convenience API for accessing layers, frames, tags and fully blended images.

Structs

Enums