Module aseprite_loader::loader
source · Expand description
This module contains the actual loader API. This API is based on the
binary-module of this crate and does provide a convenience API for
accessing layers, frames, tags and fully blended images.
Structs
- This can be used to load an Aseprite file.
- A frame in the file
- A cel in a frame
- A layer in the file
- A tag in the file